/*
 * ePeriodique: an EFL Periodic Table Of Elements
 * Copyright (C) 2010-2014 Jerome Pinot <ngc891@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "eperiodique.h"

/* xpos and ypos are the positions in the UI table */
struct element_struct
{
   int atomic_number;
   int xpos;
   int ypos;
   char *symbol;
   char *name;
   double atomic_weight;
   char *category;
   char *electron;
   char *phase;
   double density;
   double mp;
   double bp;
   double sp;
   char *lattice;
   char *discovery;
   char *CAS;
   char *oxidation;
   double en_pauling;
   double en_allredrochow;
   int cov_radius;
   int vdw_radius;
};

/* this is all the chemical data of ePeriodique, comes from Wikipedia */
static const struct element_struct elements_data[ZMAX] = {

  { 1, 0, 0, "H",  N_("hydrogen"), 1.00794, N_("other nonmetals"), "1s¹", N_("gas"), 0.08988,
     14.1, 20.39, 0, "hP", "1766 (Henry Cavendish)", "1333-74-0", "+1, -1", 2.20, 2.20, 23, 109 },

  { 2, 17, 0, "He", N_("helium"), 4.002602, N_("noble gases"), "1s²", N_("gas"), 0.1785,
     0.95, 4.22, 0, "hP", "1868 (Janssen/Lockyer)", "7440-59-7", "0", 0, 5.50, 0, 140 },

  { 3, 0, 1, "Li", N_("lithium"), 6.941, N_("alkali metals"), "[He] 2s¹", N_("solid"), 534,
     453.7, 1615, 0, "cI", "1817 (Johan August Arfwedson)", "7439-93-2", "+1", 0.98, 0.97, 68, 182 },

  { 4, 1, 1, "Be", N_("beryllium"), 9.012182, N_("alkaline earth metals"), "[He] 2s²", N_("solid"), 1848,
     1560, 2744, 0, "cI", "1798 (Louis Nicolas Vauquelin)", "7440-41-7", "+2", 1.57, 1.47, 35, 0 },

  { 5, 12, 1, "B",  N_("boron"), 10.811, N_("metalloids"), "[He] 2s²2p¹", N_("solid"), 2340,
     2348, 4273, 0, "hR", "1808 (Gay-Lussac/Thénard/Davy)", "7440-42-8", "+3", 2.04, 2.01, 83, 0 },

  { 6, 13, 1, "C",  N_("carbon"), 12.0107, N_("other nonmetals"), "[He] 2s²2p²", N_("solid"), 2267,
     0, 0, 4098, " ", "?", "7440-44-0", "+4, +2, -1", 2.55, 2.50, 68, 170 },

  { 7, 14, 1, "N",  N_("nitrogen"), 14.0067, N_("other nonmetals"), "[He] 2s²2p³", N_("gas"), 1.2506,
     63.15, 77.352, 0, "hP", "1772 (Daniel Rutherford)", "7727-37-9", "+5, +4, +3, +2, +1, -1, -2, -3", 3.04, 3.07, 68, 155 },

  { 8, 15, 1, "O",  N_("oxygen"), 15.9994, N_("other nonmetals"), "[He] 2s²2p⁴", N_("gas"), 1.429,
     54.36, 90.20, 0, "cP", "1774 (Joseph Priestley)", "7782-44-7", "−2", 3.44, 3.50, 68, 152 },

  { 9, 16, 1, "F",  N_("fluorine"), 18.9984032,  N_("halogens"), "[He] 2s²2p⁵", N_("gas"), 1.696,
     53.48, 85.03, 0, "cP", "1886 (Henri Moissan)", "7782-41-4", "-1", 3.98, 4.10, 64, 147 },

  { 10, 17, 1, "Ne", N_("neon"), 20.1797, N_("noble gases"), "[He] 2s²2p⁶", N_("gas"), 0.89990,
     24.541, 27.097, 0, "cF", "1898 (Ramsay/Travers)", "7440-01-9", "0", 0, 4.84, 0, 154 },

  { 11, 0, 2, "Na", N_("sodium"), 22.98976928, N_("alkali metals"), "[Ne] 3s¹", N_("solid"), 971,
     370.95, 1156, 0, "cI", "1807 (Humphry Davy)", "7440-23-5", "+1", 0.93, 1.01, 97, 227 },

  { 12, 1, 2, "Mg", N_("magnesium"), 24.3050, N_("alkaline earth metals"), "[Ne] 3s²", N_("solid"), 1738,
     923, 1363, 0, "hP", "1808 (Humphry Davy)", "7439-95-4", "+2", 1.31, 1.23, 110, 173 },

  { 13, 12, 2, "Al", N_("aluminium"), 26.9815386, N_("other metals"), "[Ne] 3s²3p¹", N_("solid"), 2698.9,
     933.47, 2792, 0, "cF", "1827 (Hans Christian Ørsted)", "7429-90-5", "+3", 1.61, 1.47, 135, 0 },

  { 14, 13, 2, "Si", N_("silicon"), 28.0855, N_("metalloids"), "[Ne] 3s²3p²", N_("solid"), 2330,
     1687, 3538, 0, "cF", "1824 (Jöns Jacob Berzelius)", "7440-21-3", "+4, +2, -4", 1.90, 1.74, 120, 210 },

  { 15, 14, 2, "P", N_("phosphorus"), 30.973762, N_("other nonmetals"), "[Ne] 3s²3p³", N_("solid"), 1820,
     317.30, 553.7, 0, "aP", "1669 (Hennig Brand)", "7723-14-0", "+5, +3, -3", 2.19, 2.06, 105, 180 },

  { 16, 15, 2, "S",  N_("sulfur"), 32.065, N_("other nonmetals"), "[Ne] 3s²3p⁴", N_("solid"), 2070,
     388.36, 717.76, 0, "oP", "?", "7704-34-9", "+6, +4, -2", 2.58, 2.44, 102, 180 },

  { 17, 16, 2, "Cl", N_("chlorine"), 35.453, N_("halogens"), "[Ne] 3s²3p⁵", N_("gas"), 3.214,
     171.7, 239.11, 0, "oP", "1774 (Carl Wilhelm Scheele)", "7782-50-5", "+7, +5, +1, -1", 3.16, 2.83, 99, 175 },

  { 18, 17, 2, "Ar", N_("argon"), 39.948, N_("noble gases"), "[He] 3s²3p⁶", N_("gas"), 1.7837,
     83.79, 87.30, 0, "cF", "1894 (Rayleigh/Ramsay)", "7440–37–1", "0", 0, 3.20, 151, 188 },

  { 19, 0, 3, "K",  N_("potassium"), 39.0983, N_("alkali metals"), "[Ar] 4s¹", N_("solid"), 890,
     336.7, 1032, 0, "cI", "1807 (Humphry Davy)", "7440-09-7", "+1", 0.82, 0.91, 133, 275 },

  { 20, 1, 3, "Ca", N_("calcium"), 40.078, N_("alkaline earth metals"), "[Ar] 4s²", N_("solid"), 1540,
     1115, 1757, 0, "cF", "1808 (Humphry Davy)", "7440-70-2", "+2", 1.00, 1.04, 99, 0 },

  { 21, 2, 3, "Sc", N_("scandium"), 44.955912, N_("transition elements"), "[Ar] 3d¹4s²", N_("solid"), 2989,
     1814, 3109, 0, "hP", "1879 (Lars Fredrik Nilson)", "7440-20-2", "+3", 1.36, 1.20, 144, 0 },

  { 22, 3, 3, "Ti", N_("titanium"), 47.867, N_("transition elements"), "[Ar] 3d²4s²", N_("solid"), 4510,
     1941, 3560, 0, "hP", "1791 (William Gregor)", "7440-32-6", "+4, +3, +2", 1.54, 1.32, 147, 0 },

  { 23, 4, 3, "V",  N_("vanadium"), 50.9415, N_("transition elements"), "[Ar] 3d³4s²", N_("solid"), 6000,
     2183, 3680, 0, "cI", "1801 (Andrés Manuel del Río)", "7440-62-2", "+5, +4, +3, +2", 1.63, 1.45, 133, 0 },

  { 24, 5, 3, "Cr", N_("chromium"), 51.9961, N_("transition elements"), "[Ar] 3d⁵4s¹", N_("solid"), 7150,
     2180, 2944, 0, "cI", "1797 (Louis Nicolas Vauquelin)", "7440-47-3", "+6, +3, +2", 1.66, 1.56, 135, 0 },

  { 25, 6, 3, "Mn", N_("manganese"), 54.938045, N_("transition elements"), "[Ar] 3d⁵4s²", N_("solid"), 7210,
     1519, 2334, 0, "cI", "1774 (Johan Gottlieb Gahn)", "7439-96-5", "+7, +4, +3, +2", 1.55, 1.60, 135, 0 },

  { 26, 7, 3, "Fe", N_("iron"), 55.845, N_("transition elements"), "[Ar] 3d⁶4s²", N_("solid"), 7874,
     1811, 3134, 0, "cI", "?", "7439-89-6", "+3, +2", 1.83, 1.64, 134, 0 },

  { 27, 8, 3, "Co", N_("cobalt"), 58.933195, N_("transition elements"), "[Ar] 3d⁷4s²", N_("solid"), 8900,
     1768, 3200, 0, "hP", "1735 (Georg Brandt)", "7440-48-4", "+3, +2", 1.88, 1.70, 133, 0 },

  { 28, 9, 3, "Ni", N_("nickel"), 58.6934, N_("transition elements"), "[Ar] 3d⁸4s²", N_("solid"), 8902,
     1728, 3186, 0, "cF", "1751 (Axel Fredrik Cronstedt)", "7440-02-0", "+3, +2", 1.91, 1.75, 0, 163 },

  { 29, 10, 3, "Cu", N_("copper"), 63.546, N_("transition elements"), "[Ar] 3d¹⁰4s¹", N_("solid"), 8960,
     1357.77, 2835, 0, "cF", "?", "7440-50-8", "+2, +1", 1.90, 1.75, 152, 140 },

  { 30, 11, 3, "Zn", N_("zinc"), 65.38, N_("transition elements"), "[Ar] 3d¹⁰4s²", N_("solid"), 7134,
     692.68, 1180, 0, "hP", "?", "7440-66-6", "+2", 1.65, 1.66, 145, 139 },

  { 31, 12, 3, "Ga", N_("gallium"), 69.723, N_("other metals"), "[Ar] 4s²3d¹⁰4p¹", N_("solid"), 5904,
     302.91, 2477, 0, "oP", "1875 (Paul-Émile Lecoq de Boisbaudran)", "7440-55-3", "+3", 1.81, 1.82, 122, 187 },

  { 32, 13, 3, "Ge", N_("germanium"), 72.64, N_("metalloids"), "[Ar] 4s²3d¹⁰4p²", N_("solid"), 5323,
     1211.40, 3106, 0, "cP", "1886 (Clemens Winkler)", "7440-56-4", "+4, +2", 2.01, 2.02, 117, 0 },

  { 33, 14, 3, "As", N_("arsenic"), 74.92160, N_("metalloids"), "[Ar] 4s²3d¹⁰4p³", N_("solid"), 5750,
     0, 0, 889, "hR", "?", "7440-38-2", "+5, +3, -3", 2.18, 2.20, 121, 185 },

  { 34, 15, 3, "Se", N_("selenium"), 78.96, N_("other nonmetals"), "[Ar] 4s²3d¹⁰4p⁴", N_("solid"), 4790,
     494, 958, 0, "hP", "1817 (Jöns Jakob Berzelius)", "7782-49-2", "+6, +4, -2", 2.55, 2.48, 122, 190 },

  { 35, 16, 3, "Br", N_("bromine"), 79.904, N_("halogens"), "[Ar] 4s²3d¹⁰4p⁵", N_("liquid"), 3120,
     266.0, 332.0, 0, "oP", "1825 (Carl Jacob Löwig)", "7726-95-6", "+5, +1, -1", 2.96, 2.74, 121, 185 },

  { 36, 17, 3, "Kr", N_("krypton"), 83.798, N_("noble gases"), "[Ar] 4s²3d¹⁰4p⁶", N_("gas"), 3.733,
     115.79, 119.8, 0, "cF", "1898 (Ramsay/Travers)", "7439-90-9", "0", 3.00, 2.94, 0, 202 },

  { 37, 0, 4, "Rb", N_("rubidium"), 85.4678, N_("alkali metals"), "[Kr] 5s¹", N_("solid"), 1532,
     312.45, 961, 0, "cI", "1861 (Bunsen/Kirchhoff)","7440-17-7", "+1", 0.82, 0.89, 147, 0 },

  { 38, 1, 4, "Sr", N_("strontium"), 87.62, N_("alkaline earth metals"), "[Kr] 5s²", N_("solid"), 2640,
     1050, 1655, 0, "cF", "1790 (Adair Crawford)", "7440-24-6", "+2", 0.95, 0.99, 112, 0 },

  { 39, 2, 4, "Y",  N_("yttrium"), 88.90585, N_("transition elements"), "[Kr] 4d¹5s²", N_("solid"), 4469,
     1795, 3618, 0, "hP", "1789 (Johan Gadolin)", "7440-65-5", "+3", 1.22, 1.11, 178, 0 },

  { 40, 3, 4, "Zr", N_("zirconium"), 91.224, N_("transition elements"), "[Kr] 5s²4d²", N_("solid"), 6520,
     2128, 4682, 0, "hP", "1789 (Martin Heinrich Klaproth)", "7440-67-7", "+4", 1.33, 1.22, 156, 0 },

  { 41, 4, 4, "Nb", N_("niobium"), 92.90638, N_("transition elements"), "[Kr] 4d⁴5s¹", N_("solid"), 8570,
     2750, 5017, 0, "cI", "1801 (Charles Hatchett)", "7440-03-1", "+5, +3", 1.60, 1.23, 148, 0 },

  { 42, 5, 4, "Mo", N_("molybdenum"), 95.96, N_("transition elements"), "[Kr] 5s¹4d⁵", N_("solid"), 10220,
     2896, 4912, 0, "cI", "1778 (Carl Welhelm Scheele)", "7439-98-7", "+6", 2.16, 1.30, 147, 0 },

  { 43, 6, 4, "Tc", N_("technetium"), 97.9072, N_("transition elements"), "[Kr] 4d⁵5s²", N_("solid"), 11500,
     2430, 4538, 0, "hP", "1936 (Perrier/Segrè)", "7440-26-8", "+7, +6, +4", 1.90, 1.36, 135, 0 },

  { 44, 7, 4, "Ru", N_("ruthenium"), 101.07, N_("transition elements"), "[Kr] 4d⁷5s¹", N_("solid"), 12100,
     2607, 4423, 0, "hP", "1844 (Karl Klaus)", "7440-18-8", "+3", 2.20, 1.42, 140, 0 },

  { 45, 8, 4, "Rh", N_("rhodium"), 102.90550, N_("transition elements"), "[Kr] 5s¹4d⁸", N_("solid"), 12410,
     2237, 3968, 0, "cF", "1803 (William Hyde Wollaston)", "7440-16-6", "+3", 2.28, 1.45, 145, 0 },

  { 46, 9, 4, "Pd", N_("palladium"), 106.42, N_("transition elements"), "[Kr] 4d¹⁰", N_("solid"), 12020,
     1828.0, 3236, 0, "cF", "1803 (William Hyde Wollaston)", "7440-05-3", "+3, +2", 2.20, 1.35, 0, 163 },

  { 47, 10, 4, "Ag", N_("silver"), 107.8682, N_("transition elements"), "[Kr] 4d¹⁰5s¹", N_("solid"), 10500,
     1234.93, 2435, 0, "cF", "?", "7440-22-4", "+1", 1.93, 1.42, 159, 172 },

  { 48, 11, 4, "Cd", N_("cadmium"), 112.411, N_("transition elements"), "[Kr] 5s²4d¹⁰", N_("solid"), 8690,
     594.22, 1040, 0, "hP", "1817 (Stromeyer/Hermann)", "7440-43-9", "+2", 1.69, 1.46, 169, 158 },

  { 49, 12, 4, "In", N_("indium"), 114.818, N_("other metals"), "[Kr] 4d¹⁰5s²5p¹", N_("solid"), 7310,
     429.75, 2345, 0, "tP", "1863 (Reich/Richter)", "7440-74-6", "+3", 1.78, 1.49, 163, 193 },

  { 50, 13, 4, "Sn", N_("tin"), 118.710, N_("other metals"), "[Kr] 4d¹⁰5s²5p²", N_("solid"), 7290,
     505.08, 2875, 0, "tP", "?", "7440-31-5", "+4, +2", 1.96, 1.72, 146, 217 },

  { 51, 14, 4, "Sb", N_("antimony"), 121.760, N_("metalloids"), "[Kr] 4d¹⁰5s²5p³", N_("solid"), 6680,
     903.78, 1860, 0, "hP", "?", "7440-36-0", "+5, +3, -3", 2.05, 1.82, 146, 0 },

  { 52, 15, 4, "Te", N_("tellurium"), 127.60, N_("metalloids"), "[Kr] 4d¹⁰5s²5p⁴", N_("solid"), 6230,
     722.66, 1261, 0, "hP", "1782 (Franz-Joseph Müller von Reichenstein)", "13494-80-9", "+6, +4, -2", 2.10, 2.01, 147, 206 },

  { 53, 16, 4, "I",  N_("iodine"), 126.90447, N_("halogens"), "[Kr] 4d¹⁰5s²5p⁵", N_("solid"), 4930,
     386.9, 457.6, 0, "oP", "1811 (Bernard Courtois)", "7553-56-2", "+7, +5, +1, -1", 2.66, 2.21, 140, 198 },

  { 54, 17, 4, "Xe", N_("xenon"), 131.293, N_("noble gases"), "[Kr] 5s²4d¹⁰5p⁶", N_("gas"), 5.89,
     161.41, 165.06, 0, "cF", "1898 (Ramsay/Travers)", "7440-63-3", "0", 2.60, 2.40, 0, 216 },

  { 55, 0, 5, "Cs", N_("caesium"), 132.9054519, N_("alkali metals"), "[Xe] 6s¹", N_("solid"), 1873,
     301.59, 944, 0, "cI", "1860 (Bunsen/Kirchhoff)", "7440-46-2", "+1", 0.79, 0.86, 167, 0 },

  { 56, 1, 5, "Ba", N_("barium"), 137.327, N_("alkaline earth metals"), "[Xe] 6s²", N_("solid"), 3620, 
     1000, 2170, 0, "cI", "1808 (Humphry Davy)", "7440-39-3", "+2", 0.89, 0.97, 134, 0 },

  { 57, 2, 8, "La", N_("lanthanum"), 138.90547, N_("lanthanides"), "[Xe] 5d¹6s²", N_("solid"), 6145,
     1193, 3737, 0, "hP", "1839 (Carl Gustav Mosander)", "7439-91-0", "+3", 1.10, 1.08, 187, 0 },

  { 58, 3, 8, "Ce", N_("cerium"), 140.116, N_("lanthanides"), "[Xe] 4f¹5d¹6s²", N_("solid"), 6770,
     1072, 3716, 0, "cF", "1803 (Berzelius/Hisinger/Klaproth)", "7440-45-1", "+4, +3", 1.12, 1.08, 183, 0 },

  { 59, 4, 8, "Pr", N_("praseodymium"), 140.90765, N_("lanthanides"), "[Xe] 4f³6s²", N_("solid"), 6773,
     1204, 3793, 0, "hP", "1885 (Carl Auer von Welsbach)", "7440-10-0", "+3", 1.13, 1.07, 182, 0 },

  { 60, 5, 8, "Nd", N_("neodymium"), 144.242, N_("lanthanides"), "[Xe] 4f⁴6s²", N_("solid"), 7008,
     1289, 3347, 0, "hP", "1885 (Carl Auer von Welsbach)", "7440-00-8", "+3", 1.14, 1.07, 181, 0 },

  { 61, 6, 8, "Pm", N_("promethium"), 144.9127, N_("lanthanides"), "[Xe] 4f⁵6s²", N_("solid"), 7264,
     1315, 3273, 0, "hP", "1945 (Marinsky/Glendenin/Coryell)", "7440-12-2", "+3", 0, 1.07, 180, 0 },

  { 62, 7, 8, "Sm", N_("samarium"), 150.36, N_("lanthanides"), "[Xe] 6s²4f⁶", N_("solid"), 7520,
     1345, 2067, 0, "hR", "1879 (Paul-Émile Lecoq de Boisbaudran)", "7440-19-9", "+3, +2", 1.17, 1.07, 180, 0 },

  { 63, 8, 8, "Eu", N_("europium"), 151.964, N_("lanthanides"), "[Xe] 4f⁷6s²", N_("solid"), 5244,
     1095, 1869, 0, "cI", "1896 (Eugène-Anatole Demarçay)", "7440-53-1", "+3, +2", 0, 1.01, 199, 0 },

  { 64, 9, 8, "Gd", N_("gadolinium"), 157.25, N_("lanthanides"), "[Xe] 4f⁷5d¹6s²", N_("solid"), 7901,
     1586, 3546, 0, "hP", "1880 (Jean Charles Galissard de Marignac)", "7440-54-2", "+3", 1.20, 1.11, 179, 0 },

  { 65, 10, 8, "Tb", N_("terbium"), 158.92535, N_("lanthanides"), "[Xe] 4f⁹6s²", N_("solid"), 8230,
     1629, 3503, 0, "hP", "1843 (Carl Gustaf Mosander)", "7440-27-9", "+3", 0, 1.10, 176, 0 },

  { 66, 11, 8, "Dy", N_("dysprosium"), 162.500, N_("lanthanides"), "[Xe] 4f¹⁰6s²", N_("solid"), 8551,
     1685, 2840, 0, "hP", "1886 (Paul-Émile Lecoq de Boisbaudran)", "7429-91-6", "+3", 1.22, 1.10, 175, 0 },

  { 67, 12, 8, "Ho", N_("holmium"), 164.93032, N_("lanthanides"), "[Xe] 4f¹¹6s²", N_("solid"), 8795,
     1745, 2973, 0, "hP", "1878 (Delafontaine/Soret/Cleve)", "7440-60-0", "+3", 1.23, 1.10, 174, 0 },

  { 68, 13, 8, "Er", N_("erbium"), 167.259, N_("lanthanides"), "[Xe] 4f¹²6s²", N_("solid"), 9066,
     1802, 3141, 0, "hP", "1843 (Carl Gustaf Mosander)", "7440-52-0", "+3", 1.24, 1.11, 173, 0 },

  { 69, 14, 8, "Tm", N_("thulium"), 168.93421, N_("lanthanides"), "[Xe] 4f¹³6s²", N_("solid"), 9321,
     1818, 2223, 0, "hP", "1879 (Per Teodor Cleve)", "7440-30-4", "+3", 1.25, 1.11, 172, 0 },

  { 70, 15, 8, "Yb", N_("ytterbium"), 173.054, N_("lanthanides"), "[Xe] 4f¹⁴6s²", N_("solid"), 6903,
     1097, 1469, 0, "cF", "1878 (Jean Charles Galissard de Marignac)", "7440-64-4", "+3, +2", 0, 1.06, 194, 0 },

  { 71, 16, 8, "Lu", N_("lutetium"), 174.9668, N_("lanthanides"), "[Xe] 4f¹⁴6s²5d¹", N_("solid"), 9841,
     1936, 3675, 0, "hP", "1907 (Urbain/von Welsbach/James)", "7439-94-3", "+3", 1.27, 1.14, 172, 0 },

  { 72, 3, 5, "Hf", N_("hafnium"), 178.49, N_("transition elements"), "[Xe] 4f¹⁴5d²6s²", N_("solid"), 13310,
     2506, 4876, 0, "hP", "1923 (Coster/von Hevesy)", "7440-58-6", "+4", 1.30, 1.23, 157, 0 },

  { 73, 4, 5, "Ta", N_("tantalum"), 180.94788, N_("transition elements"), "[Xe] 4f¹⁴5d³6s²", N_("solid"), 16400,
     3290, 5731, 0, "cI", "1802 (Anders Ekeberg)", "7440-25-7", "+5", 1.50, 1.33, 143, 0 },

  { 74, 5, 5, "W",  N_("tungsten"), 183.84, N_("transition elements"), "[Xe] 4f¹⁴5d⁴6s²", N_("solid"), 19300,
     3695, 5828, 0, "cI", "1783 (José/Fausto Elhuyar)", "7440-33-7", "+6", 2.36, 1.40, 137, 0 },

  { 75, 6, 5, "Re", N_("rhenium"), 186.207, N_("transition elements"), "[Xe] 4f¹⁴5d⁵6s²", N_("solid"), 20800,
     3458, 5869, 0, "hP", "1925 (Noddack/Tacke/Berg)", "7440-15-5", "+7, +6, +4", 1.90, 1.46, 135, 0 },

  { 76, 7, 5, "Os", N_("osmium"), 190.23, N_("transition elements"), "[Xe] 4f¹⁴5d⁶6s²", N_("solid"), 22587,
     3306, 5285, 0, "hP", "1803 (Tennant/Wollaston)", "7440-04-2", "+4, +3", 2.20, 1.52, 137, 0 },

  { 77, 8, 5, "Ir", N_("iridium"), 192.217, N_("transition elements"), "[Xe] 4f¹⁴5d⁷6s²", N_("solid"), 22562,
     2719, 4701, 0, "cF", "1803 (Smithson Tennant)", "7439-88-5", "+4, +3", 2.20, 1.55, 132, 0 },

  { 78, 9, 5, "Pt", N_("platinum"), 195.084, N_("transition elements"), "[Xe] 4f¹⁴5d⁹6s¹", N_("solid"), 21450,
     2041.2, 4098, 0, "cF", "1735 (Antonio de Ulloa)", "7440-06-4", "+4, +2", 2.28, 1.44, 0, 172 },

  { 79, 10, 5, "Au", N_("gold"), 196.966569, N_("transition elements"), "[Xe] 4f¹⁴5d¹⁰6s¹", N_("solid"), 19300,
     1337.33, 3129, 0, "cF", "?", "7440-57-5", "+3, +1", 2.54, 1.42, 0, 166 },

  { 80, 11, 5, "Hg", N_("mercury"), 200.59, N_("transition elements"), "[Xe] 4f¹⁴5d¹⁰6s²", N_("liquid"), 13546,
     234.32, 629.77, 0, "hR", "?", "7439-97-6", "+2, +1", 2.00, 1.44, 170, 155 },

  { 81, 12, 5, "Tl", N_("thallium"), 204.3833, N_("other metals"), "[Xe] 4f¹⁴5d¹⁰6s²6p¹", N_("solid"), 11850,
     577, 1746, 0, "hP", "1861 (William Crookes)", "7440-28-0", "+3, +1", 1.62, 1.44, 155, 196 },

  { 82, 13, 5, "Pb", N_("lead"), 207.2, N_("other metals"), "[Xe] 4f¹⁴5d¹⁰6s²6p²", N_("solid"), 11350,
     600.61, 2022, 0, "cF", "?", "7439-92-1", "+4, +2", 2.33, 1.55, 154, 202 },

  { 83, 14, 5, "Bi", N_("bismuth"), 208.98040, N_("other metals"), "[Xe] 4f¹⁴5d¹⁰6s²6p³", N_("solid"), 9790,
     544.6, 1837, 0, "mP", "1753 (Claude François Geoffroy)", "7440-69-9", "+5, +3", 2.02, 1.67, 154, 0 },

  { 84, 15, 5, "Po", N_("polonium"), 208.9824, N_("metalloids"), "[Xe] 4f¹⁴5d¹⁰6s²6p⁴", N_("solid"), 9200,
     527, 1235, 0, "cP", "Marie Sklodowska-Curie", "7440-08-6", "+4, +2", 2.00, 1.76, 168, 0 },

  { 85, 16, 5, "At", N_("astatine"), 209.9871, N_("halogens"), "[Xe] 4f¹⁴5d¹⁰6s²6p⁵", N_("solid"), 7000,
     575, 610, 0, " ", "1940 (Corson/MacKenzie/Segrè)", "7440-68-8", " ", 2.20, 1.90, 121, 0 },

  { 86, 17, 5, "Rn", N_("radon"), 222.0176, N_("noble gases"), "[Xe] 4f¹⁴5d¹⁰6s²6p⁶", N_("gas"), 9.73,
     202, 211.5, 0, "cF", "1900 (Friedrich Ernst Dorn)", "10043-92-2", "0", 0, 0, 0, 0 },

  { 87, 0, 6, "Fr", N_("francium"), 223.0197, N_("alkali metals"), "[Rn] 7s¹", N_("solid"), 1870,
     300, 950, 0, "cI", "1939 (Marguerite Perey)", "7440-73-5", "+1", 0.70, 0.86, 0, 0 },

  { 88, 1, 6, "Ra", N_("radium"), 226.0254, N_("alkaline earth metals"), "[Rn] 7s²", N_("solid"), 5000,
     969, 2010, 0, "cI", "1898 (Pierre/Marie Curie)", "7440-14-4", "+2", 0.90, 0.97, 190, 0 },

  { 89, 2, 9, "Ac", N_("actinium"), 227.0277, N_("actinides"), "[Rn] 6d¹7s²", N_("solid"), 10070,
     1323, 3471, 0, "cF", "1899 (André-Louis Debierne)", "7440-34-8", "+3", 1.10, 1.00, 188, 0 },

  { 90, 3, 9, "Th", N_("thorium"), 232.03806, N_("actinides"), "[Rn] 6d²7s²", N_("solid"), 11720,
     2023, 5061, 0, "cF", "1828 (Jöns Jakob Berzelius)", "7440-29-1", "+4", 1.30, 1.11, 179, 0 },

  { 91, 4, 9, "Pa", N_("protactinium"), 231.03588, N_("actinides"), "[Rn] 7s²6d¹5f²", N_("solid"), 15370,
     1845, 4300, 0, "tI", "1913 (Fajans/Göhring)", "7440-13-3", "+5, +4", 1.50, 1.14, 161, 0 },

  { 92, 5, 9, "U",  N_("uranium"), 238.02891, N_("actinides"), "[Rn] 5f³6d¹7s²", N_("solid"), 19100,
     1408, 4404, 0, "oP", "1789 (Martin Heinrich Klaproth)", "7440-61-1", "+6, +5, +4, +3", 1.38, 1.22, 158, 186 },

  { 93, 6, 9, "Np", N_("neptunium"), 237.0482, N_("actinides"), "[Rn] 7s²6d¹5f⁴", N_("solid"), 20250,
     917, 4273, 0, "oP", "1940 (McMillan/Abelson)", "7439-99-8", "+6, +5, +4, +3", 1.36, 1.22, 155, 0 },

  { 94, 7, 9, "Pu", N_("plutonium"), 244.0642, N_("actinides"), "[Rn] 5f⁶7s²", N_("solid"), 19840,
     913, 3501, 0, "mP", "1941 (Seaborg/McMillan/Kennedy/Wahl)", "7440-07-5", "+6, +5, +4, +3", 1.28, 1.22, 153, 0 },

  { 95, 8, 9, "Am", N_("americium"), 243.0614, N_("actinides"), "[Rn] 5f⁷7s²", N_("solid"), 12000,
     1449, 2284, 0, "hP", "1944 (Seaborg/Morgan/James/Ghiorso)", "7440-35-9", "+6, +5, +4, +3", 1.30, 1.20, 151, 0 },

  { 96, 9, 9, "Cm", N_("curium"), 247.0704, N_("actinides"), "[Rn] 5f⁷6d¹7s²", N_("solid"), 13510,
     1618, 3383, 0, "hP", "1944 (Seaborg/James/Ghiorso)", "7440-51-9", "+3", 1.30, 1.20, 99, 0 },

  { 97, 10, 9, "Bk", N_("berkelium"), 247.0703, N_("actinides"), "[Rn] 5f⁹7s²", N_("solid"), 14000,
     1269, 0, 0, "hP", "1949 (Seaborg/Ghiorso/Thompson)", "7440-40-6", "+4, +3", 1.30, 1.20, 154, 0 },

  { 98, 11, 9, "Cf", N_("californium"), 251.0796, N_("actinides"), "[Rn] 5f¹⁰7s²", N_("solid"), 15100,
     1173, 1743, 0, "hP", "1950 (Thompson/Street Jr./Ghiorso/Seaborg)", "7440-71-3", "+3", 1.30, 1.20, 183, 0 },

  { 99, 12, 9, "Es", N_("einsteinium"), 252.0830, N_("actinides"), "[Rn] 5f¹¹7s²", N_("solid"), 8840,
     1133, 0, 0, "cF", "1952, Berkeley", "7429-92-7", "+3", 1.30, 1.20, 0, 0 },

  { 100, 13, 9, "Fm", N_("fermium"), 257.0951, N_("actinides"), "[Rn] 5f¹²7s²", N_("solid"), 0,
     1800, 0, 0, " ", "1952, Berkeley", "7440-72-4", "+3", 1.30, 1.20, 0, 0 },

  { 101, 14, 9, "Md", N_("mendelevium"), 258.0984, N_("actinides"), "[Rn] 5f¹³7s²", N_("solid"), 0, 
     1100, 0, 0, " ", "1955, Berkeley", "7440-11-1", "+3, +2", 1.30, 1.20, 0, 0 },

  { 102, 15, 9, "No", N_("nobelium"), 259.1010, N_("actinides"), "[Rn] 5f¹⁴7s²", N_("solid"), 0,
     0, 0, 0, " ", "1958, Berkeley", "10028-14-5", "+3, +2", 1.30, 1.20, 0, 0 },

  { 103, 16, 9, "Lr", N_("lawrencium"), 262.1097, N_("actinides"), "[Rn] 5f¹⁴7s²7p¹", N_("solid"), 0,
     0, 0, 0, " ", "1961, Berkeley", "22537-19-5", "+3", 0, 0, 0, 0 },

  { 104, 3, 6, "Rf", N_("rutherfordium"), 261.1088, N_("transition elements"), "[Rn] 5f¹⁴6d²7s²", N_("solid"), 23000,
     2400, 5800, 0, " ", "1964, Dubna", "53850-36-5", "+4", 0, 0, 0, 0 },

  { 105, 4, 6, "Db", N_("dubnium"), 262.1141, N_("transition elements"), "[Rn] 5f¹⁴6d³7s²", N_("solid"), 0,
     0, 0, 0, " ", "1968, Dubna/Berkeley", "53850-35-4", " ", 0, 0, 0, 0 },

  { 106, 5, 6, "Sg", N_("seaborgium"), 266.1219, N_("transition elements"), "[Rn] 7s²5f¹⁴6d⁴", N_("solid"), 0,
     0, 0, 0, " ", "1974, Berkeley", "54038-81-2", " ", 0, 0, 0, 0 },

  { 107, 6, 6, "Bh", N_("bohrium"), 264.12, N_("transition elements"), "[Rn] 5f¹⁴6d⁵7s²", N_("solid"), 0,
     0, 0, 0, " ", "1981, Darmstadt", "54037-14-8", " ", 0, 0, 0, 0 },

  { 108, 7, 6, "Hs", N_("hassium"), 277, N_("transition elements"), "[Rn] 5f¹⁴6d⁶7s²", N_("solid"), 0,
     0, 0, 0, " ", "1984, Darmstadt", "54037-57-9", " ", 0, 0, 0, 0 },

  { 109, 8, 6, "Mt", N_("meitnerium"), 268.1388, N_("unknown"), "[Rn] 7s²5f¹⁴6d⁷", N_("solid"), 0,
     0, 0, 0, " ", "1982, Darmstadt", "54038-01-6", " ", 0, 0, 0, 0 },

  { 110, 9, 6, "Ds", N_("darmstadtium"), 271, N_("unknown"), "[Rn] 7s¹5f¹⁴6d⁹", N_("solid"), 0,
     0, 0, 0, " ", "1994, Darmstadt", "54083-77-1", " ", 0, 0, 0, 0 },

  { 111, 10, 6, "Rg", N_("roentgenium"), 272.1535, N_("unknown"), "[Rn] 5f¹⁴6d¹⁰7s¹", N_("solid"), 0,
     0, 0, 0, " ", "1994, Darmstadt", "54386-24-2", " ", 0, 0, 0, 0 },

  { 112, 11, 6, "Cn", N_("copernicium"), 285, N_("transition elements"), "[Rn] 5f¹⁴6d¹⁰7s²", N_("liquid"), 0,
     0, 0, 0, " ", "1996, Darmstadt", "54084-26-3", "+4, +2, 0", 0, 0, 122, 0 },

  { 113, 12, 6, "Uut", N_("ununtrium"), 286, N_("unknown"), "[Rn] 5f¹⁴6d¹⁰7s²7p¹", N_("solid"), 18000,
     700, 1400, 0, " ", " ", "54084-70-7", "+5, +3, +1", 0, 0, 136, 0 },

  { 114, 13, 6, "Fl", N_("flerovium"), 289, N_("unknown"), "[Rn] 5f¹⁴6d¹⁰7s²7p²", N_("solid"), 22000,
     340, 420, 0, " ", "1999, Dubna", "54085-16-4", "+4, +2", 0, 0, 143, 0 },

  { 115, 14, 6, "Uup", N_("ununpentium"), 288, N_("unknown"), "[Rn] 5f¹⁴6d¹⁰7s²7p³", N_("solid"), 11000,
     700, 1400, 0, " ", " ", "54085-64-2", "+3, +1", 0, 0, 162, 0 },

  { 116, 15, 6, "Lv", N_("livermorium"), 293, N_("unknown"), "[Rn] 5f¹⁴6d¹⁰7s²7p⁴", N_("unknown"), 12900,
     0, 0, 0, " ", "2009, Dubna", "54100-71-9", "+4, +2", 0, 0, 175, 0 },

  { 117, 16, 6, "Uus", N_("ununseptium"), 294, N_("unknown"), "[Rn] 5f¹⁴6d¹⁰7s²7p⁵", N_("solid"), 0,
     673, 823, 0, " ", " ", "54101-14-3", "+5, +3, +1, -1", 0, 0, 165, 0 },

  { 118, 17, 6, "Uuo", N_("ununoctium"), 294, N_("unknown"), "[Rn] 5f¹⁴6d¹⁰7s²7p⁶", N_("solid"), 13650,
     0, 350, 439, " ", " ", "54144-19-3", "+6, +4, +2, +1, 0, -1", 0, 0, 157, 0 }
};

/* vim: set ts=8 sw=3 sts=3 expandtab cino=>5n-3f0^-2{2(0W1st0 : */
