/*
 * ePeriodique: an EFL Periodic Table Of Elements
 * Copyright (C) 2010-2014 Jerome Pinot <ngc891@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "eperiodique.h"
#include "data.h"

static Eina_Bool
is_uppercase(char a)
{
   Eina_Bool uppercase = EINA_FALSE;

   if ((a > 64) && (a < 91)) uppercase = EINA_TRUE;
   return uppercase;
}

static Eina_Bool
is_lowercase(char a)
{
   Eina_Bool lowercase = EINA_FALSE;

   if ((a > 96) && (a < 123)) lowercase = EINA_TRUE;
   return lowercase;
}

static Eina_Bool
is_digit(char a)
{
   Eina_Bool digit = EINA_FALSE;

   if ((a > 47) && (a < 58)) digit = EINA_TRUE;
   return digit;
}

static double
ewdata(Eina_Strbuf *symbol)
{
   int i;
   double result = 0;

   for (i = 0; i <= ZMAX; i++)
     {
        if (!strncmp(elements_data[i].symbol, eina_strbuf_string_get(symbol), eina_strbuf_length_get(symbol)))
          {
             result = elements_data[i].atomic_weight;
             break;
          }
     }

   return result;
}

double mwcalc(const char *formula)
{
   int size, i;
   Eina_Bool ptest;
   int coeff, coeffp;
   double mass, mass_tmp;
   Eina_Strbuf *buffer;

   size = strlen(formula);
   if ( size > FMAX )
     {
        EINA_LOG_ERR("Error: formula is too long!");
        return 0;
     }

   mass = 0;
   ptest = EINA_FALSE;
   buffer = eina_strbuf_new();

   /* Parse the formula */
   for (i = 0; i < size; i++)
     {
        eina_strbuf_reset(buffer);
        /* Sane default value */
        coeff  = 1;
        coeffp = 1;
        /* Check for opening bracket */
        if (formula[i] == '(')
          {
             ptest = EINA_TRUE;
             mass_tmp = 0;
          }
        /* If bracket is closing, get its coefficient, multiply and add */
        else if (formula[i] == ')')
          {
             if (is_digit(formula[i+1]))
               coeffp = atoi(&formula[i+1]);
             mass += coeffp * mass_tmp;
             ptest = EINA_FALSE;
          }
        /* Start of symbol must be uppercase letter */
        else if (is_uppercase(formula[i]))
          {
             eina_strbuf_append_char(buffer, formula[i]);
             /* Case of 2 letters symbol */
             if (is_lowercase(formula[i+1]))
               {
                  eina_strbuf_append_char(buffer, formula[i+1]);
                  /* Case of coefficient >1 for 2 letters symbol */
                  if (is_digit(formula[i+2]))
                    coeff = atoi(&formula[i+2]);
               }
             /* Case coefficient >1 for 1 letter symbol */
             if (is_digit(formula[i+1]))
               coeff = atoi(&formula[i+1]);
             /* If open bracket, store value temporarely in mass_tmp */
             if (ptest)
               {
                  mass_tmp += coeff * ewdata(buffer);
               }
             /* Compute normally if there was no open bracket */
             else
               {
                  mass += coeff * ewdata(buffer);
               }
          }
     }

   eina_strbuf_free(buffer);

   return mass;

}

/* vim: set ts=8 sw=3 sts=3 expandtab cino=>5n-3f0^-2{2(0W1st0 : */
