/*
 * ePeriodique: an EFL Periodic Table Of Elements
 * Copyright (C) 2010-2014 Jerome Pinot <ngc891@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "eperiodique.h"
#include "data.h"

extern Evas_Object *window, *flip;
extern char edje_file[PATH_MAX];

static Evas_Object *button_prev, *button_next, *title;
Evas_Object *frame_gp, *text_gp, *frame_pp, *text_pp, *frame_ap, *text_ap;
Evas_Object *frame_pix, *image_pix, *frame_bohr, *image_bohr, *frame_latt, *image_latt;

static void
do_flip(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
{
   elm_flip_go(flip, (Elm_Flip_Mode)data);
}

static void
get_data(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
{
   signed long int i, index, atomic_number;
   signed long int prev=0, next=0;
   char message[512];
   char img_path[PATH_MAX];

   /* Get the element's index back */
   memcpy(&index, &data, sizeof(index));
   atomic_number = elements_data[index].atomic_number;

   /* First init buttons with max and min atomic number */
   for (i = 0; i < ZMAX; i++)
     {
        if (elements_data[i].atomic_number == 1)    next = i;
        if (elements_data[i].atomic_number == ZMAX) prev = i;
     }

   /* Then, replace by previous and next element (by Z) if exist */
   for (i = 0; i < ZMAX; i++)
     {
        if (elements_data[i].atomic_number == (atomic_number - 1)) prev = i;
        if (elements_data[i].atomic_number == (atomic_number + 1)) next = i;
     }

   /* Callbacks for next/previous */
   evas_object_smart_callback_del(button_next, "clicked", get_data);
   evas_object_smart_callback_add(button_next, "clicked", get_data, (void *)next);
   evas_object_smart_callback_del(button_prev, "clicked", get_data);
   evas_object_smart_callback_add(button_prev, "clicked", get_data, (void *)prev);

   /* Set title */
   elm_object_text_set(title, _(elements_data[index].name));

   /* General properties */
   snprintf(message, sizeof(message), _("Name: %s<br>"
                                        "Symbol: %s<br>"
                                        "Category: %s<br>"
                                        "Atomic number: %d<br>"
                                        "Standard atomic weight: %'g g/mol<br>"
                                        "Electron configuration: %s<br>"
                                        "Discovery: %s<br>"
                                        "CAS registry number: %s"),
            _(elements_data[index].name),
            elements_data[index].symbol,
            _(elements_data[index].category),
            elements_data[index].atomic_number,
            elements_data[index].atomic_weight,
            elements_data[index].electron,
            elements_data[index].discovery, 
            elements_data[index].CAS);
   elm_object_text_set(text_gp, message);

   /* Physical properties */
   snprintf(message, sizeof(message), _("Phase: %s<br>"
                                        "Density: %'g kg/m³<br>"
                                        "Lattice: %s<br>"
                                        "Melting point: %'g K<br>"
                                        "Boiling point: %'g K<br>"
                                        "Sublimation point: %'g K"),
            _(elements_data[index].phase),
            elements_data[index].density,
            elements_data[index].lattice,
            elements_data[index].mp,
            elements_data[index].bp,
            elements_data[index].sp);
   elm_object_text_set(text_pp, message);

   /* Atomic properties */
   snprintf(message, sizeof(message), _("Oxidation states: %s<br>"
                                        "Electronegativity (Pauling): %'.2f<br>"
                                        "Electronegativity (Allred-Rochow): %'.2f<br>"
                                        "Covalent radius: %d pm<br>"
                                        "Van der Waals radius: %d pm"),
            elements_data[index].oxidation,
            elements_data[index].en_pauling,
            elements_data[index].en_allredrochow,
            elements_data[index].cov_radius,
            elements_data[index].vdw_radius);
   elm_object_text_set(text_ap, message);

   /* Picture */
#ifdef NOPIC
   snprintf(img_path, sizeof(img_path), "%s/images/pictures/nopic.jpg", PACKAGE_DATA_DIR);
#else
   snprintf(img_path, sizeof(img_path), "%s/images/pictures/%s.jpg", PACKAGE_DATA_DIR, elements_data[index].symbol);
#endif
   elm_image_file_set(image_pix, img_path, NULL);
   elm_object_content_set(frame_pix, image_pix);

   /* Bohr model */
   snprintf(img_path, sizeof(img_path), "%s/images/models/%s.png", PACKAGE_DATA_DIR, elements_data[index].symbol);
   elm_image_file_set(image_bohr, img_path, NULL);
   elm_object_content_set(frame_bohr, image_bohr);

   /* Lattice structure */
   snprintf(message, sizeof(message), _("Lattice: %s"), elements_data[index].lattice);
   elm_object_text_set(frame_latt, message);
   snprintf(img_path, sizeof(img_path), "%s/images/lattices/%s.png", PACKAGE_DATA_DIR, elements_data[index].lattice);
   elm_image_file_set(image_latt, img_path, NULL);
}

void
show_data(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
{
   Evas_Object *vbox, *hbox, *button, *table, *icon;

   /* Add a vertical box for button bar and content */
   vbox = elm_box_add(window);
   evas_object_size_hint_weight_set(vbox, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(vbox, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_win_resize_object_add(window, vbox);
   evas_object_show(vbox);

   /* Add a horizontal box for buttons and title */
   hbox = elm_box_add(window);
   elm_box_horizontal_set(hbox, EINA_TRUE);
   evas_object_size_hint_weight_set(hbox, EVAS_HINT_EXPAND, 0.06);
   evas_object_size_hint_align_set(hbox, EVAS_HINT_FILL, EVAS_HINT_FILL);
   evas_object_show(hbox);

   /* Button for previous element */
   button_prev = elm_button_add(window);
   evas_object_size_hint_weight_set(button_prev, 0.25, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(button_prev, EVAS_HINT_FILL, EVAS_HINT_FILL);
   evas_object_show(button_prev);
   icon = elm_icon_add(window);
   elm_icon_standard_set(icon, "arrow_left");
   elm_object_part_content_set(button_prev, "icon", icon);
   evas_object_show(icon);
   elm_box_pack_end(hbox, button_prev);

   /* Title */
   title = elm_label_add(window);
   elm_object_style_set(title, "marker");
   elm_object_text_set(title, "Trololo");
   evas_object_size_hint_align_set(title, EVAS_HINT_FILL, EVAS_HINT_FILL);
   evas_object_size_hint_weight_set(title, 0.5, 0.5);
   evas_object_show(title);
   elm_box_pack_end(hbox, title);
   elm_object_scale_set(title, 2.0);

   /* Button for next element */
   button_next = elm_button_add(window);
   evas_object_size_hint_weight_set(button_next, 0.25, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(button_next, EVAS_HINT_FILL, EVAS_HINT_FILL);
   evas_object_show(button_next);
   icon = elm_icon_add(window);
   elm_icon_standard_set(icon, "arrow_right");
   elm_object_part_content_set(button_next, "icon", icon);
   evas_object_show(icon);
   elm_box_pack_end(hbox, button_next);

  /* Button for going back */
   button = elm_button_add(window);
   evas_object_size_hint_weight_set(button, 0.25, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(button, EVAS_HINT_FILL, EVAS_HINT_FILL);
   evas_object_smart_callback_add(button, "clicked", do_flip, (void *)ELM_FLIP_CUBE_RIGHT);
   evas_object_show(button);
   icon = elm_icon_add(window);
   elm_icon_standard_set(icon, "home");
   elm_object_part_content_set(button, "icon", icon);
   evas_object_show(icon);
   elm_box_pack_end(hbox, button);

   /* Place button bar */
   elm_box_pack_end(vbox, hbox);

   /* Table container */
   table = elm_table_add(window);
   evas_object_size_hint_weight_set(table, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(table, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_table_homogeneous_set(table, EINA_TRUE);
   evas_object_show(table);
   elm_box_pack_end(vbox, table);

   /* Frame for general properties */
   frame_gp = elm_frame_add(window);
   elm_object_scale_set(frame_gp, 1.2);
   evas_object_size_hint_weight_set(frame_gp, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(frame_gp, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_text_set(frame_gp, _("General properties"));

   /* Construct a text block for general properties */
   text_gp = elm_entry_add(window);
   elm_entry_editable_set(text_gp, EINA_FALSE);
   evas_object_size_hint_weight_set(text_gp, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(text_gp, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_content_set(frame_gp, text_gp);
   evas_object_show(text_gp);
   evas_object_show(frame_gp);
   elm_table_pack(table, frame_gp, 0, 0, 1, 1);

   /* Frame for physical properties */
   frame_pp = elm_frame_add(window);
   elm_object_scale_set(frame_pp, 1.2);
   evas_object_size_hint_weight_set(frame_pp, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(frame_pp, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_text_set(frame_pp, _("Physical properties"));

   /* Construct a similar text block */
   text_pp = elm_entry_add(window);
   elm_entry_editable_set(text_pp, EINA_FALSE);
   evas_object_size_hint_weight_set(text_pp, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(text_pp, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_content_set(frame_pp, text_pp);
   evas_object_show(text_pp);
   evas_object_show(frame_pp);
   elm_table_pack(table, frame_pp, 0, 1, 1, 1);

   /* Frame for atomic properties */
   frame_ap = elm_frame_add(window);
   elm_object_scale_set(frame_ap, 1.2);
   evas_object_size_hint_weight_set(frame_ap, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(frame_ap, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_text_set(frame_ap, _("Atomic properties"));

   /* Construct a similar text block */
   text_ap = elm_entry_add(window);
   elm_entry_editable_set(text_ap, EINA_FALSE);
   evas_object_size_hint_weight_set(text_ap, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(text_ap, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_content_set(frame_ap, text_ap);
   evas_object_show(text_ap);
   evas_object_show(frame_ap);
   elm_table_pack(table, frame_ap, 0, 2, 1, 1);

   /* Frame for picture */
   frame_pix = elm_frame_add(window);
   elm_object_scale_set(frame_pix, 1.2);
   evas_object_size_hint_weight_set(frame_pix, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(frame_pix, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_text_set(frame_pix, _("Appearance"));

   /* Put the picture */
   image_pix = elm_image_add(window);
   evas_object_show(image_pix);
   evas_object_show(frame_pix);
   elm_table_pack(table, frame_pix, 1, 0, 2, 2);

   /* Frame for Bohr model */
   frame_bohr = elm_frame_add(window);
   elm_object_scale_set(frame_bohr, 1.2);
   evas_object_size_hint_weight_set(frame_bohr, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(frame_bohr, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_text_set(frame_bohr, _("Bohr model"));

   /* Put the model */
   image_bohr = elm_image_add(window);
   evas_object_show(image_bohr);
   evas_object_show(frame_bohr);
   elm_table_pack(table, frame_bohr, 1, 2, 1, 1);

   /* Frame for the lattice */
   frame_latt = elm_frame_add(window);
   elm_object_scale_set(frame_latt, 1.2);
   evas_object_size_hint_weight_set(frame_latt, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(frame_latt, EVAS_HINT_FILL, EVAS_HINT_FILL);

   /* Put the lattice */
   image_latt = elm_image_add(window);
   elm_object_content_set(frame_latt, image_latt);
   evas_object_show(image_latt);
   evas_object_show(frame_latt);
   elm_table_pack(table, frame_latt, 2, 2, 1, 1);

   /* Put data in back flip and show it */
   get_data(data, NULL, NULL);
   elm_object_part_content_set(flip, "back", vbox);
   do_flip((void *)ELM_FLIP_CUBE_LEFT, NULL, NULL);
}

/* vim: set ts=8 sw=3 sts=3 expandtab cino=>5n-3f0^-2{2(0W1st0 : */
